///////////////////////////////////////////////////
// DIPSwitch.h
// part of
// DIPSwitch
// 720020-1178x
//
// Applied Data Systems
//
// Description
// -----------
// ADS boot DIP switches typically map directly to IO bits in some
// hardware on the board.  This set of classes and sample show how
// to read the state of those lines.
//
// Notes
// -----
// This sample currently only supports:
// BitsyX  (which uses two bits on the SA-1111 companion chip for the switches)
// BitsyXb (which uses to GPIO bits on the PXA270 for the switches)
// 
// History
// -------
// 720020-11781 : March 5, 04 (ctacke)
//   - Initial implementation
// 720020-11782 : July 14, 06 (jnosek)
//   - Added implementation for the BitsyXb
// 
///////////////////////////////////////////////////
#include <windows.h>

class DIPSwitch
{
	protected:
		void  *m_address;
		DWORD m_mask;
		DWORD m_shift;
		DWORD m_offset;
		
	public:
		DIPSwitch(DWORD address, DWORD offset, DWORD mask, DWORD shift);
		BYTE ReadSwitches();
};

class BitsyXSwitch : public DIPSwitch
{
	public:
		BitsyXSwitch();
};

class BitsyXbSwitch
{
	public: 
		BitsyXbSwitch();
		BYTE ReadSwitches();

	private:
		DIPSwitch dip0;
		DIPSwitch dip1;
};